/*
Name: charge QA
Data source: 30635
Created By: Jake Peterson
Last Update At: 2020-03-09T16:02:49.368Z
*/
select
from accounts_services.payments

select * 
from nac_production.order_created 

select *
from stripe.charges 